@@ -102,43 +102,56 @@ class DataNullDataSource(
         """
         return jsii.invoke(self, "outputs", [key])
 
+    @jsii.member(jsii_name="resetHasComputedDefault")
+    def reset_has_computed_default(self) -> None:
+        return jsii.invoke(self, "resetHasComputedDefault", [])
+
+    @jsii.member(jsii_name="resetInputs")
+    def reset_inputs(self) -> None:
+        return jsii.invoke(self, "resetInputs", [])
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.invoke(self, "synthesizeAttributes", [])
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="id")
+    def id(self) -> builtins.str:
+        return jsii.get(self, "id")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="random")
     def random(self) -> builtins.str:
         return jsii.get(self, "random")
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="hasComputedDefaultInput")
+    def has_computed_default_input(self) -> typing.Optional[builtins.str]:
+        return jsii.get(self, "hasComputedDefaultInput")
+
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="inputsInput")
+    def inputs_input(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        return jsii.get(self, "inputsInput")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="hasComputedDefault")
-    def has_computed_default(self) -> typing.Optional[builtins.str]:
+    def has_computed_default(self) -> builtins.str:
         return jsii.get(self, "hasComputedDefault")
 
     @has_computed_default.setter # type: ignore
-    def has_computed_default(self, value: typing.Optional[builtins.str]) -> None:
+    def has_computed_default(self, value: builtins.str) -> None:
         jsii.set(self, "hasComputedDefault", value)
 
-    @builtins.property # type: ignore
-    @jsii.member(jsii_name="id")
-    def id(self) -> typing.Optional[builtins.str]:
-        return jsii.get(self, "id")
-
-    @id.setter # type: ignore
-    def id(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "id", value)
-
     @builtins.property # type: ignore
     @jsii.member(jsii_name="inputs")
-    def inputs(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+    def inputs(self) -> typing.Mapping[builtins.str, builtins.str]:
         return jsii.get(self, "inputs")
 
     @inputs.setter # type: ignore
-    def inputs(
-        self,
-        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
-    ) -> None:
+    def inputs(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         jsii.set(self, "inputs", value)
 
 
@@ -192,7 +205,6 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("count")
@@ -201,7 +213,6 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("depends_on")
@@ -210,7 +221,6 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("lifecycle")
@@ -219,7 +229,6 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("provider")
@@ -268,10 +277,19 @@ class NullProvider(
 
         jsii.create(NullProvider, self, [scope, id, config])
 
+    @jsii.member(jsii_name="resetAlias")
+    def reset_alias(self) -> None:
+        return jsii.invoke(self, "resetAlias", [])
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.invoke(self, "synthesizeAttributes", [])
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="aliasInput")
+    def alias_input(self) -> typing.Optional[builtins.str]:
+        return jsii.get(self, "aliasInput")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="alias")
     def alias(self) -> typing.Optional[builtins.str]:
@@ -349,29 +367,33 @@ class Resource(
 
         jsii.create(Resource, self, [scope, id, config])
 
+    @jsii.member(jsii_name="resetTriggers")
+    def reset_triggers(self) -> None:
+        return jsii.invoke(self, "resetTriggers", [])
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.invoke(self, "synthesizeAttributes", [])
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="id")
-    def id(self) -> typing.Optional[builtins.str]:
+    def id(self) -> builtins.str:
         return jsii.get(self, "id")
 
-    @id.setter # type: ignore
-    def id(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "id", value)
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="triggersInput")
+    def triggers_input(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        return jsii.get(self, "triggersInput")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="triggers")
-    def triggers(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+    def triggers(self) -> typing.Mapping[builtins.str, builtins.str]:
         return jsii.get(self, "triggers")
 
     @triggers.setter # type: ignore
-    def triggers(
-        self,
-        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
-    ) -> None:
+    def triggers(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         jsii.set(self, "triggers", value)
 
 
@@ -420,7 +442,6 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("count")
@@ -429,7 +450,6 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("depends_on")
@@ -438,7 +458,6 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("lifecycle")
@@ -447,7 +466,6 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("provider")
